class InvalidAWSProfile(Exception):
    pass


class InvalidServicePrefix(Exception):
    pass


class ModelNotFound(Exception):
    pass


class ProjectNotFound(Exception):
    pass


class InvalidRuntimeException(Exception):
    pass


class UnsupportedModelFormat(Exception):
    pass


class NoCredentialsFound(Exception):
    pass


class InvalidNotebookAuthToken(Exception):
    pass


class InvalidCredentials(Exception):
    pass


class UnableToConvertNotebook(Exception):
    pass


class IntegrationError(Exception):
    pass
